@@ -261,6 +261,35 @@ Timeline <- gvisTimeline(data=datTL,
                                       colors="['#cbb69d', '#603913', '#c69c6e']"))
 plot(Timeline)
 
+## ----Gantt, results='asis', tidy=FALSE----------------------------------------
+daysToMilliseconds <- function(days){
+  days * 24 * 60 * 60 * 1000
+}
+
+dat <- data.frame(
+  taskID = c("Research", "Write", "Cite", "Complete", "Outline"),
+  taskName = c("Find sources", "Write Paper",  "Create bibliography", "Hand in paper", "Outline paper"),
+  resource = c(NA, "write", "write", "complete", "write"),
+  start = c(as.Date("2015-01-01"), NA, NA, NA, NA),
+  end = as.Date(c("2015-01-05", "2015-01-09", "2015-01-07", "2015-01-10", "2015-01-06")),
+  duration = c(NA, daysToMilliseconds(c(3, 1, 1, 1))),
+  percentComplete = c(100, 25, 20, 0, 100),
+  dependencies = c(NA, "Research, Outline", "Research", "Cite, Write", "Research")
+)
+
+gntt <- gvisGantt(dat, taskID = "taskID",
+                  taskName = "taskName", 
+                  resource = "resource",
+                  start = "start",
+                  end = "end", 
+                  duration = "duration",
+                  percentComplete = "percentComplete",
+                  dependencies = "dependencies",
+                  options = list(height = '300',
+                                 width = 'auto'))
+
+plot(gntt)
+
 ## ----WordTree, results='asis', tidy=FALSE-------------------------------------
 wt1 <- gvisWordTree(Cats, textvar = "Phrase")
 plot(wt1)
@@ -274,28 +303,3 @@ T <- gvisTable(Exports,
 GT <- gvisMerge(G,T, horizontal=TRUE) 
 plot(GT)
 
-## ----MotionChart, results='asis', tidy=FALSE----------------------------------
-Motion=gvisMotionChart(Fruits, 
-                       idvar="Fruit", 
-                       timevar="Year")
-plot(Motion)
-
-## ----MotionChartSettings, results='asis', tidy=FALSE--------------------------
-myStateSettings <-'
-{"xZoomedDataMin":1199145600000,"colorOption":"2",
-"duration":{"timeUnit":"Y","multiplier":1},"yLambda":1,
-"yAxisOption":"4","sizeOption":"_UNISIZE",
-"iconKeySettings":[],"xLambda":1,"nonSelectedAlpha":0,
-"xZoomedDataMax":1262304000000,"iconType":"LINE",
-"dimensions":{"iconDimensions":["dim0"]},
-"showTrails":false,"uniColorForNonSelected":false,
-"xAxisOption":"_TIME","orderedByX":false,"playDuration":15000,
-"xZoomedIn":false,"time":"2010","yZoomedDataMin":0,
-"yZoomedIn":false,"orderedByY":false,"yZoomedDataMax":100}
-'
-M <- gvisMotionChart(Fruits, "Fruit", "Year", options=list(state=myStateSettings))
-plot(M)
-
-
-## See demo(package='googleVis') for other available demos.
-
